@@ -6,7 +6,7 @@
 #
 
 import django.test
-import mock
+from unittest import mock
 
 from django_declarative_apis import models
 from django_declarative_apis.authentication.oauthlib import request_validator
